@@ -80,7 +80,15 @@ class FormForForm(forms.ModelForm):
         """
         self.form = form
         self.form_fields = form.fields.visible()
+        field_entries = {}
+        # If a FormEntry instance is given to edit, populate initial
+        # with its field values.
+        field_entries = {}
+        if "instance" in kwargs:
+            for field_entry in kwargs["instance"].fields.all():
+                field_entries[field_entry.field_id] = field_entry.value
         super(FormForForm, self).__init__(*args, **kwargs)
+        # Create the form fields.
         for field in self.form_fields:
             field_key = "field_%s" % field.id
             field_class = fields.CLASSES[field.field_type]
@@ -94,16 +102,17 @@ class FormForForm(forms.ModelForm):
                 field_args["choices"] = field.get_choices()
             if field_widget is not None:
                 field_args["widget"] = field_widget
-            self.initial[field_key] = field.default
+            try:
+                self.initial[field_key] = field_entries[field.id]
+            except KeyError:
+                self.initial[field_key] = field.default
             self.fields[field_key] = field_class(**field_args)
-            # Add identifying CSS classes to the field.
-            css_class = field_class.__name__.lower()
-            if field.required:
-                css_class += " required"
-                if (settings.FORMS_USE_HTML5 and
-                    field.field_type != fields.CHECKBOX_MULTIPLE):
-                    self.fields[field_key].widget.attrs["required"] = ""
-            self.fields[field_key].widget.attrs["class"] = css_class
+            # Add identifying type attr to the field for styling.
+            setattr(self.fields[field_key], "type",
+                    field_class.__name__.lower())
+            if (field.required and settings.FORMS_USE_HTML5 and
+                field.field_type != fields.CHECKBOX_MULTIPLE):
+                self.fields[field_key].widget.attrs["required"] = ""
             if field.placeholder_text and not field.default:
                 text = field.placeholder_text
                 self.fields[field_key].widget.attrs["placeholder"] = text
@@ -124,8 +133,9 @@ class FormForForm(forms.ModelForm):
                 value = fs.save(join("forms", str(uuid4()), value.name), value)
             if isinstance(value, list):
                 value = ", ".join([v.strip() for v in value])
-            if value:
-                entry.fields.create(field_id=field.id, value=value)
+            field_entry, _ = entry.fields.get_or_create(field_id=field.id)
+            field_entry.value = value
+            field_entry.save()
         return entry
 
     def email_to(self):
