@@ -3,9 +3,9 @@
 # MEZZANINE SETTINGS #
 ######################
 
-# The following Mezzanine settings are already defined in
-# mezzanine.conf.defaults, but can be uncommented below in
-# order to override their defaults.
+# The following settings are already defined in mezzanine.conf.defaults
+# with default values, but are common enough to be put here, commented
+# out, for convenient overriding.
 
 # Controls the ordering and grouping of the admin menu.
 #
@@ -56,9 +56,32 @@
 #     ),
 # )
 
-# Name of the current theme to host during theme development.
+# Setting to turn on featured images for blog posts. Defaults to False.
 #
-# THEME = ""
+# BLOG_USE_FEATURED_IMAGE = True
+
+# Turns on accounts for website visitors. Will add the
+# LOGIN_URL/LOGOUT_URL values to urlpatterns, and show login/logout
+# links in templates/includes/user_panel.html. Defaults to False.
+#
+# ACCOUNTS_ENABLED = True
+
+# If ``True``, users will be automatically redirected to HTTPS
+# for the URLs specified by the ``SSL_FORCE_URL_PREFIXES`` setting.
+#
+# SSL_ENABLED = True
+
+# Host name that the site should always be accessed via that matches
+# the SSL certificate.
+#
+# SSL_FORCE_HOST = "www.example.com"
+
+# Sequence of URL prefixes that will be forced to run over
+# SSL when ``SSL_ENABLED`` is ``True``. i.e.
+# ('/admin', '/example') would force all URLs beginning with
+# /admin or /example to run over SSL. Defaults to:
+#
+# SSL_FORCE_URL_PREFIXES = ("/admin", "/account")
 
 # If True, the south application will be automatically added to the
 # INSTALLED_APPS setting. This setting is not defined in
@@ -119,6 +142,10 @@ TEMPLATE_LOADERS = (
     "django.template.loaders.app_directories.Loader",
 )
 
+# URLs used for login/logout when ACCOUNTS_ENABLED is set to True.
+LOGIN_URL = "/account/"
+LOGOUT_URL = "/account/logout/"
+
 
 #############
 # DATABASES #
@@ -159,18 +186,29 @@ PROJECT_DIRNAME = PROJECT_ROOT.split(os.sep)[-1]
 # project specific.
 CACHE_MIDDLEWARE_KEY_PREFIX = PROJECT_DIRNAME
 
+# URL prefix for static files.
+# Example: "http://media.lawrence.com/static/"
+STATIC_URL = "/static/"
+
+# Absolute path to the directory static files should be collected to.
+# Don't put anything in this directory yourself; store your static files
+# in apps' "static/" subdirectories and in STATICFILES_DIRS.
+# Example: "/home/media/media.lawrence.com/static/"
+STATIC_ROOT = os.path.join(PROJECT_ROOT, STATIC_URL.strip("/"))
+
+# URL that handles the media served from MEDIA_ROOT. Make sure to use a
+# trailing slash.
+# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
+MEDIA_URL = STATIC_URL + "media/"
+
+# Absolute filesystem path to the directory that will hold user-uploaded files.
+# Example: "/home/media/media.lawrence.com/media/"
+MEDIA_ROOT = os.path.join(PROJECT_ROOT, *MEDIA_URL.strip("/").split("/"))
+
 # URL prefix for admin media -- CSS, JavaScript and images. Make sure to use a
 # trailing slash.
 # Examples: "http://foo.com/media/", "/media/".
-ADMIN_MEDIA_PREFIX = "/media/"
-
-# URL that handles the media served from MEDIA_ROOT. Make sure to use a
-# trailing slash if there is a path component (optional in other cases).
-# Examples: "http://media.lawrence.com", "http://example.com/media/"
-MEDIA_URL = "/site_media/"
-
-# Absolute path to the directory that holds media.
-MEDIA_ROOT = os.path.join(PROJECT_ROOT, MEDIA_URL.strip("/"))
+ADMIN_MEDIA_PREFIX = STATIC_URL + "grappelli/"
 
 # Package/module name to import the root urlpatterns from for the project.
 ROOT_URLCONF = "%s.urls" % PROJECT_DIRNAME
@@ -181,9 +219,6 @@ ROOT_URLCONF = "%s.urls" % PROJECT_DIRNAME
 # Don't forget to use absolute paths, not relative paths.
 TEMPLATE_DIRS = (os.path.join(PROJECT_ROOT, "templates"),)
 
-LOGIN_URL = "/admin/"
-LOGIN_REDIRECT_URL = "/admin/"
-
 
 ################
 # APPLICATIONS #
@@ -197,6 +232,7 @@ INSTALLED_APPS = (
     "django.contrib.sessions",
     "django.contrib.sites",
     "django.contrib.sitemaps",
+    "django.contrib.staticfiles",
     "mezzanine.boot",
     "mezzanine.conf",
     "mezzanine.core",
@@ -204,7 +240,9 @@ INSTALLED_APPS = (
     "mezzanine.blog",
     "mezzanine.forms",
     "mezzanine.pages",
+    "mezzanine.galleries",
     "mezzanine.twitter",
+    #"mezzanine.mobile",
 )
 
 # List of processors used by RequestContext to populate the context.
@@ -212,8 +250,10 @@ INSTALLED_APPS = (
 # only parameter and returns a dictionary to add to the context.
 TEMPLATE_CONTEXT_PROCESSORS = (
     "django.contrib.auth.context_processors.auth",
+    "django.contrib.messages.context_processors.messages",
     "django.core.context_processors.debug",
     "django.core.context_processors.i18n",
+    "django.core.context_processors.static",
     "django.core.context_processors.media",
     "django.core.context_processors.request",
     "mezzanine.conf.context_processors.settings",
@@ -229,8 +269,12 @@ MIDDLEWARE_CLASSES = (
     "mezzanine.core.middleware.DeviceAwareUpdateCacheMiddleware",
     "django.middleware.common.CommonMiddleware",
     "django.middleware.csrf.CsrfViewMiddleware",
+    "django.contrib.messages.middleware.MessageMiddleware",
+    "mezzanine.core.middleware.TemplateForDeviceMiddleware",
     "mezzanine.core.middleware.DeviceAwareFetchFromCacheMiddleware",
-    "mezzanine.core.middleware.AdminLoginInterfaceSelector",
+    "mezzanine.core.middleware.AdminLoginInterfaceSelectorMiddleware",
+    # Uncomment the following if using any of the SSL settings:
+    # "mezzanine.core.middleware.SSLRedirectMiddleware",
 )
 
 # Store these package names here as they may change in the future since
